# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/accesslog/v3/accesslog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/accesslog/v3/accesslog.proto',
  package='envoy.data.accesslog.v3',
  syntax='proto3',
  serialized_options=b'\n%io.envoyproxy.envoy.data.accesslog.v3B\016AccesslogProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'envoy/data/accesslog/v3/accesslog.proto\x12\x17\x65nvoy.data.accesslog.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd8\x01\n\x11TCPAccessLogEntry\x12\x43\n\x11\x63ommon_properties\x18\x01 \x01(\x0b\x32(.envoy.data.accesslog.v3.AccessLogCommon\x12L\n\x15\x63onnection_properties\x18\x02 \x01(\x0b\x32-.envoy.data.accesslog.v3.ConnectionProperties:0\x9a\xc5\x88\x1e+\n)envoy.data.accesslog.v2.TCPAccessLogEntry\"\xba\x03\n\x12HTTPAccessLogEntry\x12\x43\n\x11\x63ommon_properties\x18\x01 \x01(\x0b\x32(.envoy.data.accesslog.v3.AccessLogCommon\x12Q\n\x10protocol_version\x18\x02 \x01(\x0e\x32\x37.envoy.data.accesslog.v3.HTTPAccessLogEntry.HTTPVersion\x12?\n\x07request\x18\x03 \x01(\x0b\x32..envoy.data.accesslog.v3.HTTPRequestProperties\x12\x41\n\x08response\x18\x04 \x01(\x0b\x32/.envoy.data.accesslog.v3.HTTPResponseProperties\"U\n\x0bHTTPVersion\x12\x18\n\x14PROTOCOL_UNSPECIFIED\x10\x00\x12\n\n\x06HTTP10\x10\x01\x12\n\n\x06HTTP11\x10\x02\x12\t\n\x05HTTP2\x10\x03\x12\t\n\x05HTTP3\x10\x04:1\x9a\xc5\x88\x1e,\n*envoy.data.accesslog.v2.HTTPAccessLogEntry\"w\n\x14\x43onnectionProperties\x12\x16\n\x0ereceived_bytes\x18\x01 \x01(\x04\x12\x12\n\nsent_bytes\x18\x02 \x01(\x04:3\x9a\xc5\x88\x1e.\n,envoy.data.accesslog.v2.ConnectionProperties\"\xf2\n\n\x0f\x41\x63\x63\x65ssLogCommon\x12,\n\x0bsample_rate\x18\x01 \x01(\x01\x42\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?!\x00\x00\x00\x00\x00\x00\x00\x00\x12@\n\x19\x64ownstream_remote_address\x18\x02 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12?\n\x18\x64ownstream_local_address\x18\x03 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12>\n\x0etls_properties\x18\x04 \x01(\x0b\x32&.envoy.data.accesslog.v3.TLSProperties\x12.\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x14time_to_last_rx_byte\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x41\n\x1etime_to_first_upstream_tx_byte\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x1dtime_to_last_upstream_tx_byte\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x41\n\x1etime_to_first_upstream_rx_byte\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x1dtime_to_last_upstream_rx_byte\x18\n \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x43\n time_to_first_downstream_tx_byte\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x42\n\x1ftime_to_last_downstream_tx_byte\x18\x0c \x01(\x0b\x32\x19.google.protobuf.Duration\x12>\n\x17upstream_remote_address\x18\r \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12=\n\x16upstream_local_address\x18\x0e \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12\x18\n\x10upstream_cluster\x18\x0f \x01(\t\x12>\n\x0eresponse_flags\x18\x10 \x01(\x0b\x32&.envoy.data.accesslog.v3.ResponseFlags\x12\x30\n\x08metadata\x18\x11 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata\x12)\n!upstream_transport_failure_reason\x18\x12 \x01(\t\x12\x12\n\nroute_name\x18\x13 \x01(\t\x12G\n downstream_direct_remote_address\x18\x14 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12^\n\x14\x66ilter_state_objects\x18\x15 \x03(\x0b\x32@.envoy.data.accesslog.v3.AccessLogCommon.FilterStateObjectsEntry\x1aO\n\x17\x46ilterStateObjectsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01:.\x9a\xc5\x88\x1e)\n\'envoy.data.accesslog.v2.AccessLogCommon\"\xa3\x08\n\rResponseFlags\x12 \n\x18\x66\x61iled_local_healthcheck\x18\x01 \x01(\x08\x12\x1b\n\x13no_healthy_upstream\x18\x02 \x01(\x08\x12 \n\x18upstream_request_timeout\x18\x03 \x01(\x08\x12\x13\n\x0blocal_reset\x18\x04 \x01(\x08\x12\x1d\n\x15upstream_remote_reset\x18\x05 \x01(\x08\x12#\n\x1bupstream_connection_failure\x18\x06 \x01(\x08\x12\'\n\x1fupstream_connection_termination\x18\x07 \x01(\x08\x12\x19\n\x11upstream_overflow\x18\x08 \x01(\x08\x12\x16\n\x0eno_route_found\x18\t \x01(\x08\x12\x16\n\x0e\x64\x65lay_injected\x18\n \x01(\x08\x12\x16\n\x0e\x66\x61ult_injected\x18\x0b \x01(\x08\x12\x14\n\x0crate_limited\x18\x0c \x01(\x08\x12Q\n\x14unauthorized_details\x18\r \x01(\x0b\x32\x33.envoy.data.accesslog.v3.ResponseFlags.Unauthorized\x12 \n\x18rate_limit_service_error\x18\x0e \x01(\x08\x12)\n!downstream_connection_termination\x18\x0f \x01(\x08\x12%\n\x1dupstream_retry_limit_exceeded\x18\x10 \x01(\x08\x12\x1b\n\x13stream_idle_timeout\x18\x11 \x01(\x08\x12%\n\x1dinvalid_envoy_request_headers\x18\x12 \x01(\x08\x12!\n\x19\x64ownstream_protocol_error\x18\x13 \x01(\x08\x12,\n$upstream_max_stream_duration_reached\x18\x14 \x01(\x08\x12\"\n\x1aresponse_from_cache_filter\x18\x15 \x01(\x08\x12\x1e\n\x16no_filter_config_found\x18\x16 \x01(\x08\x12\x18\n\x10\x64uration_timeout\x18\x17 \x01(\x08\x1a\xcd\x01\n\x0cUnauthorized\x12J\n\x06reason\x18\x01 \x01(\x0e\x32:.envoy.data.accesslog.v3.ResponseFlags.Unauthorized.Reason\"6\n\x06Reason\x12\x16\n\x12REASON_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45XTERNAL_SERVICE\x10\x01:9\x9a\xc5\x88\x1e\x34\n2envoy.data.accesslog.v2.ResponseFlags.Unauthorized:,\x9a\xc5\x88\x1e\'\n%envoy.data.accesslog.v2.ResponseFlags\"\xf0\x06\n\rTLSProperties\x12\x46\n\x0btls_version\x18\x01 \x01(\x0e\x32\x31.envoy.data.accesslog.v3.TLSProperties.TLSVersion\x12\x36\n\x10tls_cipher_suite\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x18\n\x10tls_sni_hostname\x18\x03 \x01(\t\x12\x62\n\x1clocal_certificate_properties\x18\x04 \x01(\x0b\x32<.envoy.data.accesslog.v3.TLSProperties.CertificateProperties\x12\x61\n\x1bpeer_certificate_properties\x18\x05 \x01(\x0b\x32<.envoy.data.accesslog.v3.TLSProperties.CertificateProperties\x12\x16\n\x0etls_session_id\x18\x06 \x01(\t\x1a\xde\x02\n\x15\x43\x65rtificateProperties\x12\x65\n\x10subject_alt_name\x18\x01 \x03(\x0b\x32K.envoy.data.accesslog.v3.TLSProperties.CertificateProperties.SubjectAltName\x12\x0f\n\x07subject\x18\x02 \x01(\t\x1a\x88\x01\n\x0eSubjectAltName\x12\r\n\x03uri\x18\x01 \x01(\tH\x00\x12\r\n\x03\x64ns\x18\x02 \x01(\tH\x00:Q\x9a\xc5\x88\x1eL\nJenvoy.data.accesslog.v2.TLSProperties.CertificateProperties.SubjectAltNameB\x05\n\x03san:B\x9a\xc5\x88\x1e=\n;envoy.data.accesslog.v2.TLSProperties.CertificateProperties\"W\n\nTLSVersion\x12\x17\n\x13VERSION_UNSPECIFIED\x10\x00\x12\t\n\x05TLSv1\x10\x01\x12\x0b\n\x07TLSv1_1\x10\x02\x12\x0b\n\x07TLSv1_2\x10\x03\x12\x0b\n\x07TLSv1_3\x10\x04:,\x9a\xc5\x88\x1e\'\n%envoy.data.accesslog.v2.TLSProperties\"\xa7\x04\n\x15HTTPRequestProperties\x12\x45\n\x0erequest_method\x18\x01 \x01(\x0e\x32#.envoy.config.core.v3.RequestMethodB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x0e\n\x06scheme\x18\x02 \x01(\t\x12\x11\n\tauthority\x18\x03 \x01(\t\x12*\n\x04port\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x12\n\nuser_agent\x18\x06 \x01(\t\x12\x0f\n\x07referer\x18\x07 \x01(\t\x12\x15\n\rforwarded_for\x18\x08 \x01(\t\x12\x12\n\nrequest_id\x18\t \x01(\t\x12\x15\n\roriginal_path\x18\n \x01(\t\x12\x1d\n\x15request_headers_bytes\x18\x0b \x01(\x04\x12\x1a\n\x12request_body_bytes\x18\x0c \x01(\x04\x12[\n\x0frequest_headers\x18\r \x03(\x0b\x32\x42.envoy.data.accesslog.v3.HTTPRequestProperties.RequestHeadersEntry\x1a\x35\n\x13RequestHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:4\x9a\xc5\x88\x1e/\n-envoy.data.accesslog.v2.HTTPRequestProperties\"\x93\x04\n\x16HTTPResponseProperties\x12\x33\n\rresponse_code\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1e\n\x16response_headers_bytes\x18\x02 \x01(\x04\x12\x1b\n\x13response_body_bytes\x18\x03 \x01(\x04\x12^\n\x10response_headers\x18\x04 \x03(\x0b\x32\x44.envoy.data.accesslog.v3.HTTPResponseProperties.ResponseHeadersEntry\x12`\n\x11response_trailers\x18\x05 \x03(\x0b\x32\x45.envoy.data.accesslog.v3.HTTPResponseProperties.ResponseTrailersEntry\x12\x1d\n\x15response_code_details\x18\x06 \x01(\t\x1a\x36\n\x14ResponseHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15ResponseTrailersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:5\x9a\xc5\x88\x1e\x30\n.envoy.data.accesslog.v2.HTTPResponsePropertiesBA\n%io.envoyproxy.envoy.data.accesslog.v3B\x0e\x41\x63\x63\x65sslogProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_address__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_HTTPACCESSLOGENTRY_HTTPVERSION = _descriptor.EnumDescriptor(
  name='HTTPVersion',
  full_name='envoy.data.accesslog.v3.HTTPAccessLogEntry.HTTPVersion',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROTOCOL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP10', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP11', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP2', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP3', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=878,
  serialized_end=963,
)
_sym_db.RegisterEnumDescriptor(_HTTPACCESSLOGENTRY_HTTPVERSION)

_RESPONSEFLAGS_UNAUTHORIZED_REASON = _descriptor.EnumDescriptor(
  name='Reason',
  full_name='envoy.data.accesslog.v3.ResponseFlags.Unauthorized.Reason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REASON_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL_SERVICE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3435,
  serialized_end=3489,
)
_sym_db.RegisterEnumDescriptor(_RESPONSEFLAGS_UNAUTHORIZED_REASON)

_TLSPROPERTIES_TLSVERSION = _descriptor.EnumDescriptor(
  name='TLSVersion',
  full_name='envoy.data.accesslog.v3.TLSProperties.TLSVersion',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERSION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_1', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_2', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_3', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4344,
  serialized_end=4431,
)
_sym_db.RegisterEnumDescriptor(_TLSPROPERTIES_TLSVERSION)


_TCPACCESSLOGENTRY = _descriptor.Descriptor(
  name='TCPAccessLogEntry',
  full_name='envoy.data.accesslog.v3.TCPAccessLogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_properties', full_name='envoy.data.accesslog.v3.TCPAccessLogEntry.common_properties', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_properties', full_name='envoy.data.accesslog.v3.TCPAccessLogEntry.connection_properties', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.data.accesslog.v2.TCPAccessLogEntry',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=353,
  serialized_end=569,
)


_HTTPACCESSLOGENTRY = _descriptor.Descriptor(
  name='HTTPAccessLogEntry',
  full_name='envoy.data.accesslog.v3.HTTPAccessLogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_properties', full_name='envoy.data.accesslog.v3.HTTPAccessLogEntry.common_properties', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='envoy.data.accesslog.v3.HTTPAccessLogEntry.protocol_version', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='envoy.data.accesslog.v3.HTTPAccessLogEntry.request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='envoy.data.accesslog.v3.HTTPAccessLogEntry.response', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HTTPACCESSLOGENTRY_HTTPVERSION,
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.data.accesslog.v2.HTTPAccessLogEntry',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=572,
  serialized_end=1014,
)


_CONNECTIONPROPERTIES = _descriptor.Descriptor(
  name='ConnectionProperties',
  full_name='envoy.data.accesslog.v3.ConnectionProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='received_bytes', full_name='envoy.data.accesslog.v3.ConnectionProperties.received_bytes', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sent_bytes', full_name='envoy.data.accesslog.v3.ConnectionProperties.sent_bytes', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.data.accesslog.v2.ConnectionProperties',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1016,
  serialized_end=1135,
)


_ACCESSLOGCOMMON_FILTERSTATEOBJECTSENTRY = _descriptor.Descriptor(
  name='FilterStateObjectsEntry',
  full_name='envoy.data.accesslog.v3.AccessLogCommon.FilterStateObjectsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.data.accesslog.v3.AccessLogCommon.FilterStateObjectsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.data.accesslog.v3.AccessLogCommon.FilterStateObjectsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2405,
  serialized_end=2484,
)

_ACCESSLOGCOMMON = _descriptor.Descriptor(
  name='AccessLogCommon',
  full_name='envoy.data.accesslog.v3.AccessLogCommon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='envoy.data.accesslog.v3.AccessLogCommon.sample_rate', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\024\022\022\031\000\000\000\000\000\000\360?!\000\000\000\000\000\000\000\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream_remote_address', full_name='envoy.data.accesslog.v3.AccessLogCommon.downstream_remote_address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream_local_address', full_name='envoy.data.accesslog.v3.AccessLogCommon.downstream_local_address', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_properties', full_name='envoy.data.accesslog.v3.AccessLogCommon.tls_properties', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='envoy.data.accesslog.v3.AccessLogCommon.start_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_last_rx_byte', full_name='envoy.data.accesslog.v3.AccessLogCommon.time_to_last_rx_byte', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_first_upstream_tx_byte', full_name='envoy.data.accesslog.v3.AccessLogCommon.time_to_first_upstream_tx_byte', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_last_upstream_tx_byte', full_name='envoy.data.accesslog.v3.AccessLogCommon.time_to_last_upstream_tx_byte', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_first_upstream_rx_byte', full_name='envoy.data.accesslog.v3.AccessLogCommon.time_to_first_upstream_rx_byte', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_last_upstream_rx_byte', full_name='envoy.data.accesslog.v3.AccessLogCommon.time_to_last_upstream_rx_byte', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_first_downstream_tx_byte', full_name='envoy.data.accesslog.v3.AccessLogCommon.time_to_first_downstream_tx_byte', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_last_downstream_tx_byte', full_name='envoy.data.accesslog.v3.AccessLogCommon.time_to_last_downstream_tx_byte', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_remote_address', full_name='envoy.data.accesslog.v3.AccessLogCommon.upstream_remote_address', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_local_address', full_name='envoy.data.accesslog.v3.AccessLogCommon.upstream_local_address', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_cluster', full_name='envoy.data.accesslog.v3.AccessLogCommon.upstream_cluster', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_flags', full_name='envoy.data.accesslog.v3.AccessLogCommon.response_flags', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.data.accesslog.v3.AccessLogCommon.metadata', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_transport_failure_reason', full_name='envoy.data.accesslog.v3.AccessLogCommon.upstream_transport_failure_reason', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_name', full_name='envoy.data.accesslog.v3.AccessLogCommon.route_name', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream_direct_remote_address', full_name='envoy.data.accesslog.v3.AccessLogCommon.downstream_direct_remote_address', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_state_objects', full_name='envoy.data.accesslog.v3.AccessLogCommon.filter_state_objects', index=20,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ACCESSLOGCOMMON_FILTERSTATEOBJECTSENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036)\n\'envoy.data.accesslog.v2.AccessLogCommon',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1138,
  serialized_end=2532,
)


_RESPONSEFLAGS_UNAUTHORIZED = _descriptor.Descriptor(
  name='Unauthorized',
  full_name='envoy.data.accesslog.v3.ResponseFlags.Unauthorized',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason', full_name='envoy.data.accesslog.v3.ResponseFlags.Unauthorized.reason', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RESPONSEFLAGS_UNAUTHORIZED_REASON,
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.data.accesslog.v2.ResponseFlags.Unauthorized',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3343,
  serialized_end=3548,
)

_RESPONSEFLAGS = _descriptor.Descriptor(
  name='ResponseFlags',
  full_name='envoy.data.accesslog.v3.ResponseFlags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='failed_local_healthcheck', full_name='envoy.data.accesslog.v3.ResponseFlags.failed_local_healthcheck', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_healthy_upstream', full_name='envoy.data.accesslog.v3.ResponseFlags.no_healthy_upstream', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_request_timeout', full_name='envoy.data.accesslog.v3.ResponseFlags.upstream_request_timeout', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_reset', full_name='envoy.data.accesslog.v3.ResponseFlags.local_reset', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_remote_reset', full_name='envoy.data.accesslog.v3.ResponseFlags.upstream_remote_reset', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_connection_failure', full_name='envoy.data.accesslog.v3.ResponseFlags.upstream_connection_failure', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_connection_termination', full_name='envoy.data.accesslog.v3.ResponseFlags.upstream_connection_termination', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_overflow', full_name='envoy.data.accesslog.v3.ResponseFlags.upstream_overflow', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_route_found', full_name='envoy.data.accesslog.v3.ResponseFlags.no_route_found', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay_injected', full_name='envoy.data.accesslog.v3.ResponseFlags.delay_injected', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fault_injected', full_name='envoy.data.accesslog.v3.ResponseFlags.fault_injected', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limited', full_name='envoy.data.accesslog.v3.ResponseFlags.rate_limited', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unauthorized_details', full_name='envoy.data.accesslog.v3.ResponseFlags.unauthorized_details', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limit_service_error', full_name='envoy.data.accesslog.v3.ResponseFlags.rate_limit_service_error', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream_connection_termination', full_name='envoy.data.accesslog.v3.ResponseFlags.downstream_connection_termination', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_retry_limit_exceeded', full_name='envoy.data.accesslog.v3.ResponseFlags.upstream_retry_limit_exceeded', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_idle_timeout', full_name='envoy.data.accesslog.v3.ResponseFlags.stream_idle_timeout', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invalid_envoy_request_headers', full_name='envoy.data.accesslog.v3.ResponseFlags.invalid_envoy_request_headers', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream_protocol_error', full_name='envoy.data.accesslog.v3.ResponseFlags.downstream_protocol_error', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_max_stream_duration_reached', full_name='envoy.data.accesslog.v3.ResponseFlags.upstream_max_stream_duration_reached', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_from_cache_filter', full_name='envoy.data.accesslog.v3.ResponseFlags.response_from_cache_filter', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_filter_config_found', full_name='envoy.data.accesslog.v3.ResponseFlags.no_filter_config_found', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration_timeout', full_name='envoy.data.accesslog.v3.ResponseFlags.duration_timeout', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESPONSEFLAGS_UNAUTHORIZED, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.data.accesslog.v2.ResponseFlags',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2535,
  serialized_end=3594,
)


_TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME = _descriptor.Descriptor(
  name='SubjectAltName',
  full_name='envoy.data.accesslog.v3.TLSProperties.CertificateProperties.SubjectAltName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='envoy.data.accesslog.v3.TLSProperties.CertificateProperties.SubjectAltName.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns', full_name='envoy.data.accesslog.v3.TLSProperties.CertificateProperties.SubjectAltName.dns', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036L\nJenvoy.data.accesslog.v2.TLSProperties.CertificateProperties.SubjectAltName',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='san', full_name='envoy.data.accesslog.v3.TLSProperties.CertificateProperties.SubjectAltName.san',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4138,
  serialized_end=4274,
)

_TLSPROPERTIES_CERTIFICATEPROPERTIES = _descriptor.Descriptor(
  name='CertificateProperties',
  full_name='envoy.data.accesslog.v3.TLSProperties.CertificateProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject_alt_name', full_name='envoy.data.accesslog.v3.TLSProperties.CertificateProperties.subject_alt_name', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject', full_name='envoy.data.accesslog.v3.TLSProperties.CertificateProperties.subject', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.data.accesslog.v2.TLSProperties.CertificateProperties',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3992,
  serialized_end=4342,
)

_TLSPROPERTIES = _descriptor.Descriptor(
  name='TLSProperties',
  full_name='envoy.data.accesslog.v3.TLSProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tls_version', full_name='envoy.data.accesslog.v3.TLSProperties.tls_version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_cipher_suite', full_name='envoy.data.accesslog.v3.TLSProperties.tls_cipher_suite', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_sni_hostname', full_name='envoy.data.accesslog.v3.TLSProperties.tls_sni_hostname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_certificate_properties', full_name='envoy.data.accesslog.v3.TLSProperties.local_certificate_properties', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer_certificate_properties', full_name='envoy.data.accesslog.v3.TLSProperties.peer_certificate_properties', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_session_id', full_name='envoy.data.accesslog.v3.TLSProperties.tls_session_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TLSPROPERTIES_CERTIFICATEPROPERTIES, ],
  enum_types=[
    _TLSPROPERTIES_TLSVERSION,
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.data.accesslog.v2.TLSProperties',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3597,
  serialized_end=4477,
)


_HTTPREQUESTPROPERTIES_REQUESTHEADERSENTRY = _descriptor.Descriptor(
  name='RequestHeadersEntry',
  full_name='envoy.data.accesslog.v3.HTTPRequestProperties.RequestHeadersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.RequestHeadersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.RequestHeadersEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4924,
  serialized_end=4977,
)

_HTTPREQUESTPROPERTIES = _descriptor.Descriptor(
  name='HTTPRequestProperties',
  full_name='envoy.data.accesslog.v3.HTTPRequestProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_method', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.request_method', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheme', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.scheme', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.authority', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.port', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_agent', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.user_agent', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='referer', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.referer', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forwarded_for', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.forwarded_for', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.request_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='original_path', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.original_path', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_bytes', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.request_headers_bytes', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_body_bytes', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.request_body_bytes', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers', full_name='envoy.data.accesslog.v3.HTTPRequestProperties.request_headers', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPREQUESTPROPERTIES_REQUESTHEADERSENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.data.accesslog.v2.HTTPRequestProperties',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4480,
  serialized_end=5031,
)


_HTTPRESPONSEPROPERTIES_RESPONSEHEADERSENTRY = _descriptor.Descriptor(
  name='ResponseHeadersEntry',
  full_name='envoy.data.accesslog.v3.HTTPResponseProperties.ResponseHeadersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.data.accesslog.v3.HTTPResponseProperties.ResponseHeadersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.data.accesslog.v3.HTTPResponseProperties.ResponseHeadersEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5399,
  serialized_end=5453,
)

_HTTPRESPONSEPROPERTIES_RESPONSETRAILERSENTRY = _descriptor.Descriptor(
  name='ResponseTrailersEntry',
  full_name='envoy.data.accesslog.v3.HTTPResponseProperties.ResponseTrailersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.data.accesslog.v3.HTTPResponseProperties.ResponseTrailersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.data.accesslog.v3.HTTPResponseProperties.ResponseTrailersEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5455,
  serialized_end=5510,
)

_HTTPRESPONSEPROPERTIES = _descriptor.Descriptor(
  name='HTTPResponseProperties',
  full_name='envoy.data.accesslog.v3.HTTPResponseProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_code', full_name='envoy.data.accesslog.v3.HTTPResponseProperties.response_code', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_bytes', full_name='envoy.data.accesslog.v3.HTTPResponseProperties.response_headers_bytes', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_body_bytes', full_name='envoy.data.accesslog.v3.HTTPResponseProperties.response_body_bytes', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers', full_name='envoy.data.accesslog.v3.HTTPResponseProperties.response_headers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_trailers', full_name='envoy.data.accesslog.v3.HTTPResponseProperties.response_trailers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_code_details', full_name='envoy.data.accesslog.v3.HTTPResponseProperties.response_code_details', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPRESPONSEPROPERTIES_RESPONSEHEADERSENTRY, _HTTPRESPONSEPROPERTIES_RESPONSETRAILERSENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.data.accesslog.v2.HTTPResponseProperties',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5034,
  serialized_end=5565,
)

_TCPACCESSLOGENTRY.fields_by_name['common_properties'].message_type = _ACCESSLOGCOMMON
_TCPACCESSLOGENTRY.fields_by_name['connection_properties'].message_type = _CONNECTIONPROPERTIES
_HTTPACCESSLOGENTRY.fields_by_name['common_properties'].message_type = _ACCESSLOGCOMMON
_HTTPACCESSLOGENTRY.fields_by_name['protocol_version'].enum_type = _HTTPACCESSLOGENTRY_HTTPVERSION
_HTTPACCESSLOGENTRY.fields_by_name['request'].message_type = _HTTPREQUESTPROPERTIES
_HTTPACCESSLOGENTRY.fields_by_name['response'].message_type = _HTTPRESPONSEPROPERTIES
_HTTPACCESSLOGENTRY_HTTPVERSION.containing_type = _HTTPACCESSLOGENTRY
_ACCESSLOGCOMMON_FILTERSTATEOBJECTSENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ACCESSLOGCOMMON_FILTERSTATEOBJECTSENTRY.containing_type = _ACCESSLOGCOMMON
_ACCESSLOGCOMMON.fields_by_name['downstream_remote_address'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_ACCESSLOGCOMMON.fields_by_name['downstream_local_address'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_ACCESSLOGCOMMON.fields_by_name['tls_properties'].message_type = _TLSPROPERTIES
_ACCESSLOGCOMMON.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACCESSLOGCOMMON.fields_by_name['time_to_last_rx_byte'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ACCESSLOGCOMMON.fields_by_name['time_to_first_upstream_tx_byte'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ACCESSLOGCOMMON.fields_by_name['time_to_last_upstream_tx_byte'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ACCESSLOGCOMMON.fields_by_name['time_to_first_upstream_rx_byte'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ACCESSLOGCOMMON.fields_by_name['time_to_last_upstream_rx_byte'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ACCESSLOGCOMMON.fields_by_name['time_to_first_downstream_tx_byte'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ACCESSLOGCOMMON.fields_by_name['time_to_last_downstream_tx_byte'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ACCESSLOGCOMMON.fields_by_name['upstream_remote_address'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_ACCESSLOGCOMMON.fields_by_name['upstream_local_address'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_ACCESSLOGCOMMON.fields_by_name['response_flags'].message_type = _RESPONSEFLAGS
_ACCESSLOGCOMMON.fields_by_name['metadata'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._METADATA
_ACCESSLOGCOMMON.fields_by_name['downstream_direct_remote_address'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_ACCESSLOGCOMMON.fields_by_name['filter_state_objects'].message_type = _ACCESSLOGCOMMON_FILTERSTATEOBJECTSENTRY
_RESPONSEFLAGS_UNAUTHORIZED.fields_by_name['reason'].enum_type = _RESPONSEFLAGS_UNAUTHORIZED_REASON
_RESPONSEFLAGS_UNAUTHORIZED.containing_type = _RESPONSEFLAGS
_RESPONSEFLAGS_UNAUTHORIZED_REASON.containing_type = _RESPONSEFLAGS_UNAUTHORIZED
_RESPONSEFLAGS.fields_by_name['unauthorized_details'].message_type = _RESPONSEFLAGS_UNAUTHORIZED
_TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME.containing_type = _TLSPROPERTIES_CERTIFICATEPROPERTIES
_TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME.oneofs_by_name['san'].fields.append(
  _TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME.fields_by_name['uri'])
_TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME.fields_by_name['uri'].containing_oneof = _TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME.oneofs_by_name['san']
_TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME.oneofs_by_name['san'].fields.append(
  _TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME.fields_by_name['dns'])
_TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME.fields_by_name['dns'].containing_oneof = _TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME.oneofs_by_name['san']
_TLSPROPERTIES_CERTIFICATEPROPERTIES.fields_by_name['subject_alt_name'].message_type = _TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME
_TLSPROPERTIES_CERTIFICATEPROPERTIES.containing_type = _TLSPROPERTIES
_TLSPROPERTIES.fields_by_name['tls_version'].enum_type = _TLSPROPERTIES_TLSVERSION
_TLSPROPERTIES.fields_by_name['tls_cipher_suite'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_TLSPROPERTIES.fields_by_name['local_certificate_properties'].message_type = _TLSPROPERTIES_CERTIFICATEPROPERTIES
_TLSPROPERTIES.fields_by_name['peer_certificate_properties'].message_type = _TLSPROPERTIES_CERTIFICATEPROPERTIES
_TLSPROPERTIES_TLSVERSION.containing_type = _TLSPROPERTIES
_HTTPREQUESTPROPERTIES_REQUESTHEADERSENTRY.containing_type = _HTTPREQUESTPROPERTIES
_HTTPREQUESTPROPERTIES.fields_by_name['request_method'].enum_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._REQUESTMETHOD
_HTTPREQUESTPROPERTIES.fields_by_name['port'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTPREQUESTPROPERTIES.fields_by_name['request_headers'].message_type = _HTTPREQUESTPROPERTIES_REQUESTHEADERSENTRY
_HTTPRESPONSEPROPERTIES_RESPONSEHEADERSENTRY.containing_type = _HTTPRESPONSEPROPERTIES
_HTTPRESPONSEPROPERTIES_RESPONSETRAILERSENTRY.containing_type = _HTTPRESPONSEPROPERTIES
_HTTPRESPONSEPROPERTIES.fields_by_name['response_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTPRESPONSEPROPERTIES.fields_by_name['response_headers'].message_type = _HTTPRESPONSEPROPERTIES_RESPONSEHEADERSENTRY
_HTTPRESPONSEPROPERTIES.fields_by_name['response_trailers'].message_type = _HTTPRESPONSEPROPERTIES_RESPONSETRAILERSENTRY
DESCRIPTOR.message_types_by_name['TCPAccessLogEntry'] = _TCPACCESSLOGENTRY
DESCRIPTOR.message_types_by_name['HTTPAccessLogEntry'] = _HTTPACCESSLOGENTRY
DESCRIPTOR.message_types_by_name['ConnectionProperties'] = _CONNECTIONPROPERTIES
DESCRIPTOR.message_types_by_name['AccessLogCommon'] = _ACCESSLOGCOMMON
DESCRIPTOR.message_types_by_name['ResponseFlags'] = _RESPONSEFLAGS
DESCRIPTOR.message_types_by_name['TLSProperties'] = _TLSPROPERTIES
DESCRIPTOR.message_types_by_name['HTTPRequestProperties'] = _HTTPREQUESTPROPERTIES
DESCRIPTOR.message_types_by_name['HTTPResponseProperties'] = _HTTPRESPONSEPROPERTIES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TCPAccessLogEntry = _reflection.GeneratedProtocolMessageType('TCPAccessLogEntry', (_message.Message,), {
  'DESCRIPTOR' : _TCPACCESSLOGENTRY,
  '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.TCPAccessLogEntry)
  })
_sym_db.RegisterMessage(TCPAccessLogEntry)

HTTPAccessLogEntry = _reflection.GeneratedProtocolMessageType('HTTPAccessLogEntry', (_message.Message,), {
  'DESCRIPTOR' : _HTTPACCESSLOGENTRY,
  '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.HTTPAccessLogEntry)
  })
_sym_db.RegisterMessage(HTTPAccessLogEntry)

ConnectionProperties = _reflection.GeneratedProtocolMessageType('ConnectionProperties', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONPROPERTIES,
  '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.ConnectionProperties)
  })
_sym_db.RegisterMessage(ConnectionProperties)

AccessLogCommon = _reflection.GeneratedProtocolMessageType('AccessLogCommon', (_message.Message,), {

  'FilterStateObjectsEntry' : _reflection.GeneratedProtocolMessageType('FilterStateObjectsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ACCESSLOGCOMMON_FILTERSTATEOBJECTSENTRY,
    '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.AccessLogCommon.FilterStateObjectsEntry)
    })
  ,
  'DESCRIPTOR' : _ACCESSLOGCOMMON,
  '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.AccessLogCommon)
  })
_sym_db.RegisterMessage(AccessLogCommon)
_sym_db.RegisterMessage(AccessLogCommon.FilterStateObjectsEntry)

ResponseFlags = _reflection.GeneratedProtocolMessageType('ResponseFlags', (_message.Message,), {

  'Unauthorized' : _reflection.GeneratedProtocolMessageType('Unauthorized', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSEFLAGS_UNAUTHORIZED,
    '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.ResponseFlags.Unauthorized)
    })
  ,
  'DESCRIPTOR' : _RESPONSEFLAGS,
  '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.ResponseFlags)
  })
_sym_db.RegisterMessage(ResponseFlags)
_sym_db.RegisterMessage(ResponseFlags.Unauthorized)

TLSProperties = _reflection.GeneratedProtocolMessageType('TLSProperties', (_message.Message,), {

  'CertificateProperties' : _reflection.GeneratedProtocolMessageType('CertificateProperties', (_message.Message,), {

    'SubjectAltName' : _reflection.GeneratedProtocolMessageType('SubjectAltName', (_message.Message,), {
      'DESCRIPTOR' : _TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME,
      '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
      # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.TLSProperties.CertificateProperties.SubjectAltName)
      })
    ,
    'DESCRIPTOR' : _TLSPROPERTIES_CERTIFICATEPROPERTIES,
    '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.TLSProperties.CertificateProperties)
    })
  ,
  'DESCRIPTOR' : _TLSPROPERTIES,
  '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.TLSProperties)
  })
_sym_db.RegisterMessage(TLSProperties)
_sym_db.RegisterMessage(TLSProperties.CertificateProperties)
_sym_db.RegisterMessage(TLSProperties.CertificateProperties.SubjectAltName)

HTTPRequestProperties = _reflection.GeneratedProtocolMessageType('HTTPRequestProperties', (_message.Message,), {

  'RequestHeadersEntry' : _reflection.GeneratedProtocolMessageType('RequestHeadersEntry', (_message.Message,), {
    'DESCRIPTOR' : _HTTPREQUESTPROPERTIES_REQUESTHEADERSENTRY,
    '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.HTTPRequestProperties.RequestHeadersEntry)
    })
  ,
  'DESCRIPTOR' : _HTTPREQUESTPROPERTIES,
  '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.HTTPRequestProperties)
  })
_sym_db.RegisterMessage(HTTPRequestProperties)
_sym_db.RegisterMessage(HTTPRequestProperties.RequestHeadersEntry)

HTTPResponseProperties = _reflection.GeneratedProtocolMessageType('HTTPResponseProperties', (_message.Message,), {

  'ResponseHeadersEntry' : _reflection.GeneratedProtocolMessageType('ResponseHeadersEntry', (_message.Message,), {
    'DESCRIPTOR' : _HTTPRESPONSEPROPERTIES_RESPONSEHEADERSENTRY,
    '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.HTTPResponseProperties.ResponseHeadersEntry)
    })
  ,

  'ResponseTrailersEntry' : _reflection.GeneratedProtocolMessageType('ResponseTrailersEntry', (_message.Message,), {
    'DESCRIPTOR' : _HTTPRESPONSEPROPERTIES_RESPONSETRAILERSENTRY,
    '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.HTTPResponseProperties.ResponseTrailersEntry)
    })
  ,
  'DESCRIPTOR' : _HTTPRESPONSEPROPERTIES,
  '__module__' : 'envoy.data.accesslog.v3.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.accesslog.v3.HTTPResponseProperties)
  })
_sym_db.RegisterMessage(HTTPResponseProperties)
_sym_db.RegisterMessage(HTTPResponseProperties.ResponseHeadersEntry)
_sym_db.RegisterMessage(HTTPResponseProperties.ResponseTrailersEntry)


DESCRIPTOR._options = None
_TCPACCESSLOGENTRY._options = None
_HTTPACCESSLOGENTRY._options = None
_CONNECTIONPROPERTIES._options = None
_ACCESSLOGCOMMON_FILTERSTATEOBJECTSENTRY._options = None
_ACCESSLOGCOMMON.fields_by_name['sample_rate']._options = None
_ACCESSLOGCOMMON._options = None
_RESPONSEFLAGS_UNAUTHORIZED._options = None
_RESPONSEFLAGS._options = None
_TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME._options = None
_TLSPROPERTIES_CERTIFICATEPROPERTIES._options = None
_TLSPROPERTIES._options = None
_HTTPREQUESTPROPERTIES_REQUESTHEADERSENTRY._options = None
_HTTPREQUESTPROPERTIES.fields_by_name['request_method']._options = None
_HTTPREQUESTPROPERTIES._options = None
_HTTPRESPONSEPROPERTIES_RESPONSEHEADERSENTRY._options = None
_HTTPRESPONSEPROPERTIES_RESPONSETRAILERSENTRY._options = None
_HTTPRESPONSEPROPERTIES._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/local_ratelimit/v3/local_rate_limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.extensions.common.ratelimit.v3 import ratelimit_pb2 as envoy_dot_extensions_dot_common_dot_ratelimit_dot_v3_dot_ratelimit__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from envoy.type.v3 import token_bucket_pb2 as envoy_dot_type_dot_v3_dot_token__bucket__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/local_ratelimit/v3/local_rate_limit.proto',
  package='envoy.extensions.filters.http.local_ratelimit.v3',
  syntax='proto3',
  serialized_options=b'\n>io.envoyproxy.envoy.extensions.filters.http.local_ratelimit.v3B\023LocalRateLimitProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nGenvoy/extensions/filters/http/local_ratelimit/v3/local_rate_limit.proto\x12\x30\x65nvoy.extensions.filters.http.local_ratelimit.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x34\x65nvoy/extensions/common/ratelimit/v3/ratelimit.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a envoy/type/v3/token_bucket.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdd\x03\n\x0eLocalRateLimit\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12)\n\x06status\x18\x02 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatus\x12\x30\n\x0ctoken_bucket\x18\x03 \x01(\x0b\x32\x1a.envoy.type.v3.TokenBucket\x12\x46\n\x0e\x66ilter_enabled\x18\x04 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12G\n\x0f\x66ilter_enforced\x18\x05 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12R\n\x17response_headers_to_add\x18\x06 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\x08\xfa\x42\x05\x92\x01\x02\x10\n\x12S\n\x0b\x64\x65scriptors\x18\x08 \x03(\x0b\x32>.envoy.extensions.common.ratelimit.v3.LocalRateLimitDescriptor\x12\x16\n\x05stage\x18\t \x01(\rB\x07\xfa\x42\x04*\x02\x18\nB_\n>io.envoyproxy.envoy.extensions.filters.http.local_ratelimit.v3B\x13LocalRateLimitProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_extensions_dot_common_dot_ratelimit_dot_v3_dot_ratelimit__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_http__status__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_token__bucket__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_LOCALRATELIMIT = _descriptor.Descriptor(
  name='LocalRateLimit',
  full_name='envoy.extensions.filters.http.local_ratelimit.v3.LocalRateLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.http.local_ratelimit.v3.LocalRateLimit.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.extensions.filters.http.local_ratelimit.v3.LocalRateLimit.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_bucket', full_name='envoy.extensions.filters.http.local_ratelimit.v3.LocalRateLimit.token_bucket', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_enabled', full_name='envoy.extensions.filters.http.local_ratelimit.v3.LocalRateLimit.filter_enabled', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_enforced', full_name='envoy.extensions.filters.http.local_ratelimit.v3.LocalRateLimit.filter_enforced', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_to_add', full_name='envoy.extensions.filters.http.local_ratelimit.v3.LocalRateLimit.response_headers_to_add', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\020\n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='descriptors', full_name='envoy.extensions.filters.http.local_ratelimit.v3.LocalRateLimit.descriptors', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='envoy.extensions.filters.http.local_ratelimit.v3.LocalRateLimit.stage', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030\n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=813,
)

_LOCALRATELIMIT.fields_by_name['status'].message_type = envoy_dot_type_dot_v3_dot_http__status__pb2._HTTPSTATUS
_LOCALRATELIMIT.fields_by_name['token_bucket'].message_type = envoy_dot_type_dot_v3_dot_token__bucket__pb2._TOKENBUCKET
_LOCALRATELIMIT.fields_by_name['filter_enabled'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_LOCALRATELIMIT.fields_by_name['filter_enforced'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_LOCALRATELIMIT.fields_by_name['response_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERVALUEOPTION
_LOCALRATELIMIT.fields_by_name['descriptors'].message_type = envoy_dot_extensions_dot_common_dot_ratelimit_dot_v3_dot_ratelimit__pb2._LOCALRATELIMITDESCRIPTOR
DESCRIPTOR.message_types_by_name['LocalRateLimit'] = _LOCALRATELIMIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocalRateLimit = _reflection.GeneratedProtocolMessageType('LocalRateLimit', (_message.Message,), {
  'DESCRIPTOR' : _LOCALRATELIMIT,
  '__module__' : 'envoy.extensions.filters.http.local_ratelimit.v3.local_rate_limit_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.local_ratelimit.v3.LocalRateLimit)
  })
_sym_db.RegisterMessage(LocalRateLimit)


DESCRIPTOR._options = None
_LOCALRATELIMIT.fields_by_name['stat_prefix']._options = None
_LOCALRATELIMIT.fields_by_name['response_headers_to_add']._options = None
_LOCALRATELIMIT.fields_by_name['stage']._options = None
# @@protoc_insertion_point(module_scope)
